Module error

Module error 

Structs

ConvertError
Returned when a value cannot be serialized to SAS.
ParseError
Returned when a SAS document fails to parse. Always includes the line number of the offending token.